/*
 * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { FloorScene } from "./FloorScene";
import { MarkerItem } from "./items/MarkItem";
import { SGraphyLineItem, SMouseEvent } from "@sybotan-web/graphy/lib";
import { Marker } from "./types/Marker";
import { SColor, SPoint, SRect } from "@sybotan-web/draw/lib";
import { UserMark } from "./items/UserMark";

/**
 * 划分业务空间
 *
 * @author 郝建龙
 */
export class DivideFloorScene extends FloorScene {
    /** 是否开启用户标记     */
    _isMarking: boolean = false;
    get isMarking(): boolean {
        return this._isMarking;
    } // Get isMarking
    set isMarking(v: boolean) {
        if (this._isMarking === v) {
            return;
        }
        this._isMarking = v;
    } // Set isMarking

    /**
     * 构造函数
     *
     * @param   data
     */
    constructor() {
        super();
    } // Constructor

    /**
     * 点击事件
     *
     * @param   event   保存事件参数
     * @return  boolean
     */
    onMouseDown(event: SMouseEvent): boolean {
        if (this.isMarking) {
            if (this.grabItem) {
                this.grabItem.onMouseDown(event);
            } else {
                let point = new SPoint(event.x, event.y);
                let userM = new UserMark(null, point);
                this.addItem(userM);
                this.grabItem = userM;
            }
        } else {
            super.onClick(event);
        }
        return false;
    } // Function onClick
} // Class DivideFloorScene
